package fr.univ.lyon1.iut.models;

import org.hibernate.HibernateException;
import org.hibernate.Session;
import org.hibernate.SessionFactory;
import org.hibernate.Transaction;
import org.hibernate.boot.registry.StandardServiceRegistryBuilder;
import org.hibernate.cfg.Configuration;
import org.hibernate.service.ServiceRegistry;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

public class ManageFilm {
    private static SessionFactory sessionFactory;

    public ManageFilm() {
        try {
            Configuration configuration = new Configuration();
            configuration.configure();
            configuration.addAnnotatedClass(Film.class);
            ServiceRegistry serviceRegistry = new StandardServiceRegistryBuilder().applySettings(configuration.getProperties()).build();
            sessionFactory = configuration.buildSessionFactory(serviceRegistry);
        } catch (Throwable th) {
            System.err.println("Enitial SessionFactory creation failed" + th);
            throw new ExceptionInInitializerError(th);
        }
    }

    public Long addFilm(Film film) {
        Session session = sessionFactory.openSession();
        Transaction tx = null;
        Long filmID = null;

        try {
            tx = session.beginTransaction();
            filmID = (Long) session.save(film);
            tx.commit();
        } catch (HibernateException e) {
            if (tx!=null) tx.rollback();
            e.printStackTrace();
        } finally {
            session.close();
        }
        return filmID;
    }

    public List<Film> getFilms() {
        Session session = sessionFactory.openSession();
        List<Film> films = null;

        try {
            films = session.createQuery("FROM Film", Film.class).list();
        } catch (HibernateException e) {
            e.printStackTrace();
        } finally {
            session.close();
        }
        return films;
    }

    public boolean updateFilm(Film film) {
        Session session = sessionFactory.openSession();
        Transaction tx = null;
        boolean result;

        try {
            tx = session.beginTransaction();
            session.merge(film);
            tx.commit();
            result = true;
        } catch (HibernateException e) {
            if (tx!=null) tx.rollback();
            e.printStackTrace();
            result = false;
        } finally {
            session.close();
        }
        return result;
    }

    public boolean deleteFilm(Film film) {
        Session session = sessionFactory.openSession();
        Transaction tx = null;
        boolean result;

        try {
            tx = session.beginTransaction();
            session.delete(film);
            tx.commit();
            result = true;
        } catch (HibernateException e) {
            if (tx!=null) tx.rollback();
            e.printStackTrace();
            result = false;
        } finally {
            session.close();
        }
        return result;
    }
}
